(release-3007.14)=
# Salt 3007.14 release notes

<!---
Do not edit this file. This is auto generated.
Edit the templates in doc/topics/releases/templates/
for a given release.
-->


<!--
Add release specific details below
-->

<!--
Do not edit the changelog below.
This is auto generated.
-->
## Changelog

### Fixed

- Fix `mac_brew_pkg.list_pkgs` crashing or producing incorrect results when
  Homebrew returns `null` values for cask metadata:

  - When the installed version of a cask is `null` (e.g. Homebrew cannot
    determine the installed version), it is now reported as `"unknown"`
    instead of raising an error.
  - When `full_token` is `null`, it is now filtered out so that `None`
    is never used as a package name key in the returned dictionary. [#68763](https://github.com/saltstack/salt/issues/68763)
